@@ -25,46 +25,21 @@ import datetime
 import string
 import re
 from veryprettytable import VeryPrettyTable
-from pyaws import Colors
-from pyaws.utils import stdout_message, export_json_object
-from keyup.colormap import ColorMap
-from keyup.statics import PACKAGE, seed_config
-from keyup.script_utils import import_file_object, read_local_config
-from keyup.script_utils import bool_assignment, debug_mode, os_parityPath
+from libtools import Colors
+from libtools.js import export_iterobject
+from libtools import stdout_message
+from keyup.statics import PACKAGE, local_config
+from keyup.common import debug_mode, os_parityPath, distrotype, syslog_enabled
+from keyup.script_utils import bool_assignment, import_file_object, read_local_config
 from keyup import logger, __version__
-
-
-try:
-    from keyup.oscodes_unix import exit_codes
-    os_type = 'Linux'
-    splitchar = '/'                             # character for splitting paths (linux)
-    #text = Colors.BRIGHTCYAN
-    text = Colors.BLUE
-except Exception:
-    from keyup.oscodes_win import exit_codes    # non-specific os-safe codes
-    os_type = 'Windows'
-    splitchar = '\\'                            # character for splitting paths (windows)
-    text = Colors.CYAN
-
-# globals
-cm = ColorMap()
-
-
-# universal colors
-rd = Colors.RED
-act = Colors.ORANGE
-yl = Colors.YELLOW
-fs = Colors.GOLD3
-bd = Colors.BOLD
-frame = text
-bdwt = cm.bdwt
-rst = Colors.RESET
+from keyup.variables import act, bd, bdwt, cm, exit_codes, frame, rd, rst
+from keyup.variables import splitchar, text, yl, url, os_type
 
 
 # globals
-# current_config = local_config or seed_config    # NOTE: BOTH POPULATED AT ALL TIMES, RESOLVE
-seed_file = seed_config['PROJECT']['CONFIG_PATH']
-user_home = seed_config['PROJECT']['HOME']
+current_config = local_config
+seed_file = local_config['PROJECT']['CONFIG_PATH']
+user_home = local_config['PROJECT']['HOME']
 
 
 class UpdateConfig():
@@ -86,16 +61,18 @@ class UpdateConfig():
 
         """
         self.debug = debug
+
         if os.path.exists(local_file):
             self.cfg_file = local_file
             self.local_config = read_local_config(local_file)
             self.parameters = self.preload_parameters(self.local_config)
             r = self.update(cfg=self.cfg_file, debug=debug)
+
         else:
             logger.info('local config file [%s] not found, creating using defaults.' % local_file)
-            self.cfg_file = seed_config['PROJECT']['CONFIG_PATH']
-            self.local_config = seed_config
-            self.parameters = self.preload_parameters(seed_config)
+            self.cfg_file = local_config['PROJECT']['CONFIG_PATH']
+            self.local_config = local_config
+            self.parameters = self.preload_parameters(local_config)
             r = self.config_directory(cfg=self.cfg_file)
             if r:
                 self.update(cfg=self.cfg_file, debug=self.debug)
@@ -112,27 +89,30 @@ class UpdateConfig():
         params = {}
 
         try:
+
             params['enable_logging'] = current_config['LOGGING']['ENABLE_LOGGING']
             params['log_mode'] = current_config['LOGGING']['LOG_MODE']
             params['log_path'] = current_config['LOGGING']['LOG_PATH']
             params['keyage_max'] = current_config['KEY_METADATA']['KEYAGE_MAX_DAYS']
             params['keyage_min'] = current_config['KEY_METADATA']['KEYAGE_MIN_DAYS']
-            params['keyage_limit'] = seed_config['KEY_METADATA']['KEYAGE_MAX_LIMIT']
+            params['keyage_limit'] = local_config['KEY_METADATA']['KEYAGE_MAX_LIMIT']
             params['enable_keybackup'] = current_config['KEY_BACKUP']['BACKUP_ENABLE']
             params['backup_location'] = current_config['KEY_BACKUP']['BACKUP_LOCATION']
+
         except KeyError as e:
             logger.info(
                 'KeyError parsing pre-existing config (%s). Replacing config file' %
                 str(e))
             os.remove(self.cfg_file)
-            params['enable_logging'] = seed_config['LOGGING']['ENABLE_LOGGING']
-            params['log_mode'] = seed_config['LOGGING']['LOG_MODE']
-            params['log_path'] = seed_config['LOGGING']['LOG_PATH']
-            params['keyage_max'] = seed_config['KEY_METADATA']['KEYAGE_MAX_DAYS']
-            params['keyage_min'] = seed_config['KEY_METADATA']['KEYAGE_MIN_DAYS']
-            params['keyage_limit'] = seed_config['KEY_METADATA']['KEYAGE_MAX_LIMIT']
-            params['enable_keybackup'] = seed_config['KEY_BACKUP']['BACKUP_ENABLE']
-            params['backup_location'] = seed_config['KEY_BACKUP']['BACKUP_LOCATION']
+            params['enable_logging'] = local_config['LOGGING']['ENABLE_LOGGING']
+            params['log_mode'] = local_config['LOGGING']['LOG_MODE']
+            params['log_path'] = local_config['LOGGING']['LOG_PATH']
+            params['keyage_max'] = local_config['KEY_METADATA']['KEYAGE_MAX_DAYS']
+            params['keyage_min'] = local_config['KEY_METADATA']['KEYAGE_MIN_DAYS']
+            params['keyage_limit'] = local_config['KEY_METADATA']['KEYAGE_MAX_LIMIT']
+            params['enable_keybackup'] = local_config['KEY_BACKUP']['BACKUP_ENABLE']
+            params['backup_location'] = local_config['KEY_BACKUP']['BACKUP_LOCATION']
+
         return params
 
     def update(self, cfg, debug=False):
@@ -184,13 +164,13 @@ class UpdateConfig():
                     answer2 = (input(question2).upper() or 'FILE')
                     self.parameters['log_mode'] = converge_answer(question2, ['FILE', 'SYSLOG'], answer2)
                     #    stdout_message(msg)
-                    print(rst + '\n\tLogging Mode set to: %s\n' % self.parameters['log_mode'])
+                    print(rst + '\n\tLogging mode set to: %s\n' % self.parameters['log_mode'])
 
                     # Q3 logging
                     if self.parameters['log_mode'] == 'FILE':
                         default = os_parityPath(self.parameters['log_path'])
                         msg = (
-                                '\n\t{}Log file location? [ {} ]:  '.format(text, fs + default + text)
+                                '\n\t{}Log file location? [{}]:  '.format(text, url + default + rst + text)
                             )
                         # test location to ensure write compatible
                         self.parameters['log_path'] = set_writeable_location(
@@ -208,10 +188,10 @@ class UpdateConfig():
                                 message='Log file set to: %s' % os_parityPath(
                                     self.parameters['log_path'] + '/keyup.log'), indent=16
                             )
-                            self.parameters['log_path'] = os_parityPath(
-                                self.parameters['log_path'] + '/keyup.log')
+                            self.parameters['log_path'] = os_parityPath(self.parameters['log_path'] + '/keyup.log')
                             self.parameters['log_filename'] = 'keyup.log'
-                    else:
+
+                    elif syslog_enabled() is True:
                         # syslog chosen
                         if os_type == 'Windows':
                             stdout_message('Syslog is Unix-specific, setting logging to Windows FILE defaults')
@@ -219,8 +199,21 @@ class UpdateConfig():
                             self.parameters['log_path'] = os_parityPath(self.parameters['log_path'])
                             self.parameters['log_filename'] = 'keyup.log'
                         else:
-                            self.parameters['log_path'] = '/var/log/syslog'
-                            self.parameters['log_filename'] = 'syslog'
+                            logpath = '/var/log/messages' if distrotype() == 'rhel' else '/var/log/syslog'
+                            self.parameters['log_path'] = logpath
+                            self.parameters['log_filename'] = 'messages' if distrotype() == 'rhel' else 'syslog'
+
+                    else:
+                        tab = '\t'.expandtabs(22)
+                        msg = f'The system logger on the host is not configured or is \n{tab}unoperable. Defaulting to FILE logging.'
+                        stdout_message(msg, indent=17, prefix='WARN')
+                        # FILE logging defaults
+                        self.parameters['log_mode'] = 'FILE'
+                        self.parameters['log_path'] = os_parityPath(self.parameters['log_path'])
+                        self.parameters['log_filename'] = 'keyup.log'
+                        # user msg
+                        print(('\n\tLogging mode reset to: {}').expandtabs(8).format(rst + 'FILE' + text))
+
                 else:
                     self.parameters['enable_logging'] = False
 
@@ -243,7 +236,7 @@ class UpdateConfig():
                       (bd + text, str(self.parameters['enable_keybackup']), rst))
                 if self.parameters['enable_keybackup']:
                     default = self.parameters['backup_location']
-                    msg = ('\n\t{}Backup directory location? [ {} ]:  '.format(text, fs + default + text))
+                    msg = ('\n\t{}Backup directory location? [{}]:  '.format(text, url + default + rst + text))
                     # test location to ensure write compatible
                     self.parameters['backup_location'] = set_writeable_location(
                         default_location=default,
@@ -264,11 +257,11 @@ class UpdateConfig():
                         )
 
                 # Q6:  Key expiration
-                keyage_limit = seed_config['KEY_METADATA']['KEYAGE_MAX_LIMIT']
+                keyage_limit = local_config['KEY_METADATA']['KEYAGE_MAX_LIMIT']
                 display_table(header='Key Expiration',  offset=42, title=True, tabspaces=8)
                 print(self.print_header('q6'))
 
-                default = self.parameters['keyage_max'] or current_config['KEY_METADATA']['KEYAGE_MAX_DAYS']
+                default = self.parameters['keyage_max'] or local_config['KEY_METADATA']['KEYAGE_MAX_DAYS']
                 sys.stdout.write(text)
                 while True:
                     try:
@@ -339,9 +332,9 @@ class UpdateConfig():
 
     def config_directory(self, cfg):
         """ Checks config_path to ensure directories exist; if not create """
-        user_home = seed_config['PROJECT']['HOME']
-        L1_path = user_home + splitchar + seed_config['PROJECT']['CONFIG_DIR']
-        L2_path = L1_path + splitchar + seed_config['PROJECT']['CONFIG_SUBDIR']
+        user_home = local_config['PROJECT']['HOME']
+        L1_path = user_home + splitchar + local_config['PROJECT']['CONFIG_DIR']
+        L2_path = L1_path + splitchar + local_config['PROJECT']['CONFIG_SUBDIR']
 
         try:
             for path in (L1_path, L2_path):
@@ -367,7 +360,7 @@ class UpdateConfig():
                 '%s: writing local configuration file (%s)' %
                 (inspect.stack()[0][3], cfg)
             )
-            r = export_json_object(parameter_dict, filename=cfg)
+            r = export_iterobject(parameter_dict, filename=cfg)
             logger.info('%s: config file write complete (%s)' % (inspect.stack()[0][3], cfg))
 
         except OSError as e:
@@ -410,8 +403,8 @@ class UpdateConfig():
 
             """ + q2_title1 + """: syslog for logging to the system logger
 
-                        - """ + fs + """/var/log/syslog """ + text + """for ubuntu, debian-based systems
-                        - """ + fs + """/var/log/messages """ + text + """for redhat-based systems
+                        - """ + url + """/var/log/syslog""" + rst + text + """ for ubuntu, debian-based systems
+                        - """ + url + """/var/log/messages""" + rst + text + """ for redhat-based systems
 
 
             """ + q2_title2 + """:   log to a user-specified file.  Hit return or type FILE
@@ -426,10 +419,10 @@ class UpdateConfig():
         """ + rst
 
         self.q4 = text + """
-        When access keys are rotated, would you like a backup set of new keys
-        written to local disk for safekeeping? By default, newly created keys
-        only  exist in  your local awscli  configuration unless you choose to
-        enable creation of a backup set here.
+          When access keys are rotated, would you like a backup set of new keys
+          written to local disk for safekeeping? By default, newly created keys
+          only  exist in  your local awscli  configuration unless you choose to
+          enable creation of a backup set here.
         """ + rst
 
         self.q5 = text + """
@@ -443,9 +436,9 @@ class UpdateConfig():
         """ + rst
 
         self.closing_msg = '  This concludes configuration of local ' + bdwt + \
-                            PACKAGE + rst + text + ' options.' + \
-        '\n\n\tType:  $  '.expandtabs(34) + act + 'keyconfig'  + rst + \
-         text + '\n\n\tTo display the current configuration file contents'.expandtabs(19)
+            PACKAGE + rst + text + ' options.' + \
+            '\n\n\tType:  $  '.expandtabs(34) + act + 'keyconfig' + rst + \
+            text + '\n\n\tTo display the current configuration file contents'.expandtabs(19)
 
         self.closing_footer = bdwt + """
         _______________________________________________________________________
@@ -557,6 +550,17 @@ def remove_trailing_slash(path):
     return path
 
 
+def exit_processing(code=None, clear=False):
+    """Reset terminal screen colors on exit"""
+    if platform.system() == 'Windows':
+        os.system('color')
+    if clear:
+        os.system('cls' if os.name == 'nt' else 'clear')
+    if code:
+        sys.exit(code)
+    return True
+
+
 def expand_home_path(path):
     """
     Substitute ~ for actual home path
@@ -577,6 +581,52 @@ def expand_home_path(path):
     return path
 
 
+def set_writeable_location(default_location, header, message, confirmation_msg):
+    """
+    Summary:
+        - Takes user input for filesystem location.
+        - Tests to ensure location is writable
+        - Removes trailing slash (if applicable)
+    Args:
+        :default_location (str): filesystem location if no user input
+        :header (str): Header question/title to print prior to user input
+        :message (str): Message to solicit user input
+        :confirmation_msg (str): Display text after user input accepted
+    Returns:
+        :fs_location (str): writeable filesystem path
+    """
+    loop = True
+
+    while loop:
+
+        print(header)
+        sys.stdout.write(text)
+
+        fs_location = expand_home_path(
+                input(rst + message) or default_location
+            )
+
+        # test location
+        print('\r')
+        stdout_message(message='Testing write to location... ', indent=20)
+
+        r = validate_fs_location(os_parityPath(fs_location))
+
+        if r:
+            stdout_message(
+                message='successful... filesystem is writeable',
+                prefix='OK',
+                multiline=True,
+                indent=20)
+            print('\n' + rst + confirmation_msg + ' ' + url + fs_location + rst + '\n')
+            loop = False
+        else:
+            msg = 'Cannot write to location. Please retry.'
+            stdout_message(message=msg, prefix='WARN', indent=20, multiline=True)
+            print('\r')
+    return fs_location
+
+
 def validate_fs_location(path):
     """
     Summary:
@@ -616,62 +666,6 @@ def validate_fs_location(path):
     return True
 
 
-def set_writeable_location(default_location, header, message, confirmation_msg):
-    """
-    Summary:
-        - Takes user input for filesystem location.
-        - Tests to ensure location is writable
-        - Removes trailing slash (if applicable)
-    Args:
-        :default_location (str): filesystem location if no user input
-        :header (str): Header question/title to print prior to user input
-        :message (str): Message to solicit user input
-        :confirmation_msg (str): Display text after user input accepted
-    Returns:
-        :fs_location (str): writeable filesystem path
-    """
-    loop = True
-
-    while loop:
-
-        print(header); sys.stdout.write(text)
-
-        fs_location = expand_home_path(
-                input(rst + message) or default_location
-            )
-
-        # test location
-        print('\r')
-        stdout_message(message='Testing write to location... ', indent=20)
-
-        r = validate_fs_location(os_parityPath(fs_location))
-
-        if r:
-            stdout_message(
-                message='successful... filesystem is writeable',
-                prefix='OK',
-                multiline=True,
-                indent=20)
-            print('\n' + rst + confirmation_msg + ' ' + fs + fs_location + rst + '\n')
-            loop = False
-        else:
-            msg = 'Cannot write to location. Please retry.'
-            stdout_message(message=msg, prefix='WARN', indent=20, multiline=True)
-            print('\r')
-    return fs_location
-
-
-def exit_processing(code=None, clear=False):
-    """Reset terminal screen colors on exit"""
-    if platform.system() == 'Windows':
-        os.system('color')
-    if clear:
-        os.system('cls' if os.name == 'nt' else 'clear')
-    if code:
-        sys.exit(code)
-    return True
-
-
 def init(debug=False, cfg=None):
     """
     Summary:
@@ -685,13 +679,13 @@ def init(debug=False, cfg=None):
     if not cfg:
 
         # check default config dir for file
-        default_config_path = seed_config['PROJECT']['CONFIG_PATH']
+        default_config_path = local_config['PROJECT']['CONFIG_PATH']
 
         if os.path.isfile(default_config_path):
             cfg = read_local_config(default_config_path)
 
     # initialize class object with default path or fs config if it exists
-    init_cfg = cfg or seed_config
+    init_cfg = cfg or local_config
 
     if os.path.isfile(init_cfg):
         read_obj = ReadConfig(local_file=init_cfg)
